0,1,8-fach Dimmer
19,210,Rote Modul LED
17,1,Dimmer 1
17,2,Dimmer 2
17,3,Dimmer 3
17,4,Dimmer 4
17,5,Dimmer 5
17,6,Dimmer 6
17,7,Dimmer 7
17,8,Dimmer 8
16,97,Eingang 1
16,98,Eingang 2
16,99,Eingang 3
16,100,Eingang 4
16,101,Eingang 5
16,102,Eingang 6
16,103,Eingang 7
16,104,Eingang 8