0,1,SD485 Taster
20,1,Hintergrundbeleuchtung
32,1,Temperatursensor
34,1,Feuchtesensor
42,1,Taupunkt 1
39,1,Helligkeitssensor
21,49,Led 1
21,50,Led 2
21,51,Led 3
21,52,Led 4
21,53,Led 5
21,54,Led 6
16,17,Taster 1
16,18,Taster 2
16,19,Taster 3
16,20,Taster 4
16,21,Taster 5
16,22,Taster 6
16,33,Extern Taster 1
16,34,Extern Taster 2
16,35,Extern Taster 3
16,36,Extern Taster 4
16,55,Extern Taster 5
16,56,Extern Taster 6
19,65,Schalter 65
19,66,Schalter 66
19,67,Schalter 67
19,68,Schalter 68
19,69,Schalter 69
19,70,Schalter 70
21,65,Extern Led 1
21,66,Extern Led 2
21,67,Extern Led 3
21,68,Extern Led 4
21,69,Extern Led 5
21,70,Extern Led 6
32,65,Temperatur 65
32,66,Temperatur 66
32,67,Temperatur 67
32,68,Temperatur 68
32,69,Temperatur 69
32,70,Temperatur 70
34,65,Feuchtigkeit 65
34,66,Feuchtigkeit 66
34,67,Feuchtigkeit 67
34,68,Feuchtigkeit 68
34,69,Feuchtigkeit 69
34,70,Feuchtigkeit 70
