0,1,16-fach Relais
19,210,Rote Modul LED
19,17,Relais 1,RELAY
19,18,Relais 2,RELAY
19,19,Relais 3,RELAY
19,20,Relais 4,RELAY
19,21,Relais 5,RELAY
19,22,Relais 6,RELAY
19,23,Relais 7,RELAY
19,24,Relais 8,RELAY
19,33,Relais 9,RELAY
19,34,Relais 10,RELAY
19,35,Relais 11,RELAY
19,36,Relais 12,RELAY
19,37,Relais 13,RELAY
19,38,Relais 14,RELAY
19,39,Relais 15,RELAY
19,40,Relais 16,RELAY
16,97,Eingang 1,DIGITAL_IN
16,98,Eingang 2,DIGITAL_IN
16,99,Eingang 3,DIGITAL_IN
16,100,Eingang 4,DIGITAL_IN
16,101,Eingang 5,DIGITAL_IN
16,102,Eingang 6,DIGITAL_IN
16,103,Eingang 7,DIGITAL_IN
16,104,Eingang 8,DIGITAL_IN